@@ -1114,7 +1114,7 @@ use Log::Handler::Pattern;
 use UNIVERSAL;
 use base qw(Log::Handler::Levels);
 
-our $VERSION = "0.62";
+our $VERSION = "0.63";
 our $ERRSTR  = "";
 
 # $TRACE and $CALLER_LEVEL are both used as global
@@ -1251,7 +1251,11 @@ sub new {
     }, $class;
 
     if (@_) {
-        $self->add(@_);
+        if ($_[0] eq "config") {
+            $self->config(@_);
+        } else {
+            $self->add(@_);
+        }
     }
 
     return $self;
@@ -1260,6 +1264,10 @@ sub new {
 sub add {
     my $self = shift;
 
+    if ($_[0] && $_[0] eq "config") {
+        return $self->config(@_);
+    }
+
     if (@_ > 2) {
         while (@_) {
             my $type = shift;
@@ -1281,7 +1289,7 @@ sub add {
     # Create the new output-object.
     my $output = $self->_new_output($package, $h_opts, $o_opts);
 
-    # Add the output $self.
+    # Add the output to $self.
     $self->_add_output($output);
 
     return 1;
@@ -1361,7 +1369,7 @@ sub reload {
             # output-object is reloaded.
             if (!$self->output($alias)) {
                 # If the alias does not exists we use
-                # the alias that was generated on validate().
+                # the alias that was generated by validate().
                 if (!exists $n_opts->{alias}) {
                     $n_opts->{alias} = $h_opts->{alias};
                 }
@@ -1375,8 +1383,6 @@ sub reload {
         }
     };
 
-    # Something wents wrong.
-    # The error message should be in $ERRSTR.
     if ($@) {
         return $self->_raise_error($@);
     }
